@@ -5,8 +5,8 @@ use strict;
 use Carp;
 use Text::DHCPLeases::Object;
 use Text::DHCPLeases::Object::Iterator;
-
-use version; our $VERSION = qv('0.8');
+use vars qw($VERSION);
+$VERSION = '0.9';
 
 my $IPV4  = '\d{1,3}\.\d{1,3}\.\d{1,3}\.\d{1,3}';
 
@@ -218,12 +218,12 @@ L<http://rt.cpan.org>.
 
 =head1 AUTHOR
 
-Carlos Vicente  C<< <<cvicente@cpan.org>> >>
+Carlos Vicente  <cvicente@cpan.org>
 
 
 =head1 LICENCE AND COPYRIGHT
 
-Copyright (c) <2007-2010>, Carlos Vicente C<< <<cvicente@cpan.org>> >>. All rights reserved.
+Copyright (c) 2007-2010, Carlos Vicente <cvicente@cpan.org>. All rights reserved.
 
 This module is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself. See L<perlartistic>.
